@@ -9,7 +9,7 @@ elrond_wasm::imports!();
 /// The module deals with temporarily pausing contract operations.
 /// It provides a flag that contracts can use to check if owner decided to pause the entire contract.
 /// Use the features module for more granular on/off switches.
-#[elrond_wasm_derive::module(PauseModuleImpl)]
+#[elrond_wasm_derive::module]
 pub trait PauseModule {
 	#[view(isPaused)]
 	#[storage_get("pause_module:paused")]
